@@ -13,7 +13,7 @@ public:
     AccessPointGUI(QWidget *parent = 0);
     ~AccessPointGUI();
     void setConfiguration(MobileHotspotConfiguration &configuration);
-    void getConfiguration(MobileHotspotConfiguration *configuration);
+    void configuration(MobileHotspotConfiguration *configuration);
 
 private:
     Ui::AccessPointGUIClass ui;
