@@ -120,8 +120,8 @@ int HotspotHelper::enableInternetConnection(MobileHotspotConfiguration &configur
 	/* -1=fail, -2=timeout, 0=ok */
 	int ret, tries;
 	bool trying;
-	qDebug( (((QString("** Enabling internet connection to ") + configuration.apn) + " (") + (configuration.apid + ") **")).toAscii().data() );
-	ret = DBUSHelper::internetConnect(configuration.apid);
+	qDebug( (((QString("** Enabling internet connection to ") + configuration.internetAPName) + " (") + (configuration.internetAPID + ") **")).toAscii().data() );
+	ret = DBUSHelper::internetConnect(configuration.internetAPID);
 	if(ret != 0){
 		qDebug("Error while connecting to the chosen APN");
 		return -1;
@@ -141,14 +141,11 @@ int HotspotHelper::enableInternetConnection(MobileHotspotConfiguration &configur
 	return 0;
 }
 
-int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration, int *scanInterval){
+int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration){
 	/* -1=fail, 0=ok */
 	qDebug("** Preparing USB interface **");
 	int ret;
 
-	/** Save and change scan interval **/
-	APNHelper::setScanInterval(0, scanInterval);
-
 	/** Disable USB interface - may fail, not fatal unless timeout **/
 	ret = disableUSBInterface(configuration);
 	if(ret == -2){
@@ -214,7 +211,7 @@ int HotspotHelper::enableUSBInterface(MobileHotspotConfiguration &configuration)
 	int tries, ret;
 	bool cmdret, trying;
 	QString cmd("/sbin/ifconfig "); cmd += configuration.INTERFACE_USB; cmd += " ";
-	cmd += configuration.network; cmd += "1 netmask 255.255.255.0 up";
+	cmd += configuration.lanNetwork; cmd += "1 netmask 255.255.255.0 up";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
 		qDebug("FAILURE : Cannot enable USB interface");
@@ -237,14 +234,11 @@ int HotspotHelper::enableUSBInterface(MobileHotspotConfiguration &configuration)
 	return 0;
 }
 
-int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuration, int *scanInterval){
+int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuration){
 	/* -1=fail, 0=ok */
 	qDebug("** Preparing Wifi interface **");
 	int ret;
 
-	/** Save and change scan interval **/
-	APNHelper::setScanInterval(0, scanInterval);
-
 	/** Disable Wifi interface - may fail, not fatal unless timeout **/
 	ret = disableWifiInterface(configuration);
 	if(ret == -2){
@@ -254,11 +248,25 @@ int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuratio
 	else if(ret != 0)
 		qDebug("WARNING :  Was not able to disable the Wifi interface");
 
-	/** Disable power management **/
-	ret = setPowerManagement(configuration, false);
-	if(ret != 0){
-		qDebug("Error while disabling power management");
-		return -1;
+	/** Power saving - May not work on adhoc, but who knows **/
+	if(configuration.disablePowerSaving){
+		/** Switch to managed mode (to be able to change power management) - may fail, not fatal unless timeout **/
+		ret = setAdhocMode(configuration, false);
+		if(ret == -2){
+			qDebug("Error (timeout) while enabling managed mode");
+			return -1;
+		}
+		else if(ret != 0)
+			qDebug("WARNING : Was not able to enable managed mode");
+
+		/** Disable power management - may fail, not fatal unless timeout **/
+		ret = setPowerManagement(configuration, false);
+		if(ret == -2){
+			qDebug("Error (timeout) while disabling power management");
+			return -1;
+		}
+		else if(ret != 0)
+			qDebug("WARNING : Was not able to disable power management");
 	}
 
 	/** Enable Ad-Hoc mode - may fail, not fatal unless timeout **/
@@ -271,7 +279,7 @@ int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuratio
 		qDebug("WARNING : Was not able to enable ad-hoc mode");
 
 	/** Set encryption **/
-	ret = setEncryption(configuration, configuration.encryption == configuration.ENCRYPTION_WEP);
+	ret = setEncryption(configuration, configuration.encryptionType == configuration.ENCRYPTION_WEP);
 	if(ret != 0){
 		qDebug("Error while changing the encryption");
 		return -1;
@@ -362,7 +370,7 @@ int HotspotHelper::setPowerManagement(MobileHotspotConfiguration &configuration,
 	qDebug("** Modifying power management **");
 	int ret, tries;
 	bool cmdret, trying;
-	QString cmd("/sbin/iwconfig "); cmd += configuration.interface;
+	QString cmd("/sbin/iwconfig "); cmd += configuration.lanInterface;
 	cmd += management ? " power on" : " power off";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (ret != 0) ){
@@ -373,7 +381,7 @@ int HotspotHelper::setPowerManagement(MobileHotspotConfiguration &configuration,
 	while(trying && tries < MAX_TRIES){
 		tries++;
 		QString res;
-		CommandHelper::executeCommandWithStdOut(QString("/sbin/iwconfig ") + configuration.interface, &ret, &res);
+		CommandHelper::executeCommandWithStdOut(QString("/sbin/iwconfig ") + configuration.lanInterface, &ret, &res);
 		res = res.toLower();
 		if( (management && res.count("power management:on") > 0) || ((!management) && res.count("power management:off") > 0) )
 			trying = false;
@@ -381,7 +389,7 @@ int HotspotHelper::setPowerManagement(MobileHotspotConfiguration &configuration,
 			CommandHelper::executeCommand("sleep 1");
 	}
 	if(trying){
-		qDebug("FAILURE : System was too slow modifying ad-hoc mode");
+		qDebug("FAILURE : System was too slow modifying power management");
 		return -2;
 	}
 	return 0;
@@ -427,7 +435,7 @@ int HotspotHelper::setEncryption(MobileHotspotConfiguration &configuration, bool
 	QString hexkey;
 	if(encryption){
 		qDebug("Will enable encryption");
-		hexkey = keyToHex(configuration.key).toLower();
+		hexkey = keyToHex(configuration.encryptionKey).toLower();
 		cmd += " key "; cmd += hexkey; cmd += " restricted";
 	}
 	else{
@@ -474,7 +482,7 @@ int HotspotHelper::setESSID(MobileHotspotConfiguration &configuration){
 	int ret, tries;
 	bool cmdret, trying;
 	QString cmd("/sbin/iwconfig "); cmd += configuration.INTERFACE_WLAN;
-	cmd += " essid \""; cmd += configuration.apname + "\"";
+	cmd += " essid \""; cmd += configuration.hotspotName + "\"";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
 		qDebug("FAILURE : Cannot modify essid mode");
@@ -486,7 +494,7 @@ int HotspotHelper::setESSID(MobileHotspotConfiguration &configuration){
 		QString res;
 		CommandHelper::executeCommandWithStdOut(QString("/sbin/iwconfig ") + configuration.INTERFACE_WLAN, &ret, &res);
 		res = res.toLower();
-		QString searched("essid:\""); searched += configuration.apname.toLower() + "\"";
+		QString searched("essid:\""); searched += configuration.hotspotName.toLower() + "\"";
 		if(res.count(searched) > 0)
 			trying = false;
 		else
@@ -505,7 +513,7 @@ int HotspotHelper::setWifiNetwork(MobileHotspotConfiguration &configuration){
 	int ret, tries;
 	bool cmdret, trying;
 	QString cmd("/sbin/ifconfig "); cmd += configuration.INTERFACE_WLAN;
-	cmd += " "; cmd += configuration.network + "1 netmask 255.255.255.0 up";
+	cmd += " "; cmd += configuration.lanNetwork + "1 netmask 255.255.255.0 up";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
 		qDebug("FAILURE : Cannot set nework ip");
@@ -517,7 +525,7 @@ int HotspotHelper::setWifiNetwork(MobileHotspotConfiguration &configuration){
 		QString res;
 		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + configuration.INTERFACE_WLAN, &ret, &res);
 		res = res.toLower();
-		if(res.count(configuration.network + "1") > 0)
+		if(res.count(configuration.lanNetwork + "1") > 0)
 			trying = false;
 		else
 			CommandHelper::executeCommand("sleep 1");
@@ -529,7 +537,7 @@ int HotspotHelper::setWifiNetwork(MobileHotspotConfiguration &configuration){
 	return 0;
 }
 
-int HotspotHelper::unprepareUSBInterface(MobileHotspotConfiguration &configuration, int scanInterval){
+int HotspotHelper::unprepareUSBInterface(MobileHotspotConfiguration &configuration){
 	/** -1=fail, 0=ok */
 	qDebug("** Unpreparing USB interface **");
 	int res = 0, ret;
@@ -541,13 +549,10 @@ int HotspotHelper::unprepareUSBInterface(MobileHotspotConfiguration &configurati
 		res = -1;
 	}
 
-	/** Restore scan interval **/
-	APNHelper::setScanInterval(scanInterval, &ret);
-
 	return res;
 }
 
-int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configuration, int scanInterval){
+int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configuration){
 	/** -1=fail, 0=ok */
 	qDebug("** Unpreparing Wifi interface **");
 	int res = 0, ret;
@@ -573,16 +578,13 @@ int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configurat
 		res = -1;
 	}
 
-	/** Enable power management **/
+	/** Enable disablePowerSaving management **/
 	ret = setPowerManagement(configuration, true);
 	if(ret != 0){
 		qDebug("Error while enabling power management");
 		res = -1;
 	}
 
-	/** Restore scan interval **/
-	APNHelper::setScanInterval(scanInterval, &ret);
-
 	return res;
 }
 
@@ -591,17 +593,17 @@ int HotspotHelper::startDnsMasq(MobileHotspotConfiguration &configuration, QProc
 	/** Credits to Rambo for the basics of the command **/
 	qDebug("** Starting dnsmasq **");
 	QString cmd("/usr/sbin/dnsmasq");
-	cmd += " -i "; cmd += configuration.interface;
-	cmd += " -a "; cmd += configuration.network + "1";
+	cmd += " -i "; cmd += configuration.lanInterface;
+	cmd += " -a "; cmd += configuration.lanNetwork + "1";
 	cmd += " -I lo -z -x "; cmd += dnsmasqPIDFile(configuration);
-	cmd += " --dhcp-range="; cmd += configuration.network + "10,"; cmd += configuration.network + "200,6h";
+	cmd += " --dhcp-range="; cmd += configuration.lanNetwork + "10,"; cmd += configuration.lanNetwork + "200,6h";
 	cmd += " --dhcp-authoritative";
-	if(configuration.internet){
+	if(configuration.internetEnabled){
 		cmd += " --dhcp-option=3,";
-		cmd += configuration.network + "1";
+		cmd += configuration.lanNetwork + "1";
 		// option 3 = router
 	}
-	cmd += " --dhcp-option=6,"; cmd += configuration.network + "1"; // option 6 = dns server
+	cmd += " --dhcp-option=6,"; cmd += configuration.lanNetwork + "1"; // option 6 = dns server
 	bool cmdret = CommandHelper::executeCommandAsync(cmd, dnsmasqProcess, MAX_TRIES * 1000);
 	if(! cmdret){
 		qDebug("FAILURE : Cannot start dnsmasq");
@@ -612,7 +614,7 @@ int HotspotHelper::startDnsMasq(MobileHotspotConfiguration &configuration, QProc
 
 QString HotspotHelper::dnsmasqPIDFile(MobileHotspotConfiguration &configuration){
 	QString res("/var/run/dnsmasq.");
-	res += configuration.interface + ".pid";
+	res += configuration.lanInterface + ".pid";
 	return res;
 }
 
@@ -654,7 +656,7 @@ int HotspotHelper::stopDnsMasq(MobileHotspotConfiguration &configuration){
 	}
 	tries = 0; trying = true;
 	cmd = "/bin/sh -c \"ps -Ac | grep -v grep | grep dnsmasq | grep ";
-	cmd += configuration.interface + " | grep ";
+	cmd += configuration.lanInterface + " | grep ";
 	cmd += QString::number(pid) + " | wc -l\"";
 	while(trying && tries < MAX_TRIES){
 		tries++;
@@ -689,7 +691,7 @@ int HotspotHelper::setIPTables(MobileHotspotConfiguration &configuration, int *i
 		*ipforward = ret;
 	else
 		*ipforward = 0;
-	cmd = "/bin/sh -c \"echo "; cmd += configuration.internet ? "1" : "0";
+	cmd = "/bin/sh -c \"echo "; cmd += configuration.internetEnabled ? "1" : "0";
 	cmd += " > /proc/sys/net/ipv4/ip_forward\"";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
@@ -709,8 +711,8 @@ int HotspotHelper::setIPTables(MobileHotspotConfiguration &configuration, int *i
 	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -P FORWARD ACCEPT");
 	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -P INPUT ACCEPT");
 	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -P OUTPUT ACCEPT");
-	if(configuration.internet)
-		cmdret = cmdret && CommandHelper::executeCommand(QString("/usr/sbin/iptables -t nat -A POSTROUTING -s ") + configuration.network + "0/24 -j MASQUERADE");
+	if(configuration.internetEnabled)
+		cmdret = cmdret && CommandHelper::executeCommand(QString("/usr/sbin/iptables -t nat -A POSTROUTING -s ") + configuration.lanNetwork + "0/24 -j MASQUERADE");
 	if(! cmdret){
 		qDebug("FAILURE : Cannot enable our iptables");
 		return -1;
