@@ -10,9 +10,11 @@
 #define GCONF_APNAME GCONF "/name"
 #define GCONF_ENCRYPTION GCONF "/encryption"
 #define GCONF_KEY GCONF "/key"
+#define GCONF_POWER GCONF "/power"
 #define GCONF_INTERFACE GCONF "/interface"
 #define GCONF_APN GCONF "/apn"
 #define GCONF_APID GCONF "/apid"
+#define GCONF_APTYPE GCONF "/aptype"
 #define GCONF_NETWORK GCONF "/network"
 #define GCONF_INTERNET GCONF "/internet"
 #define GCONF_2G3G	GCONF "/2g3g"
@@ -35,9 +37,10 @@ public:
 	static const QString ENCRYPTION_WEP;
 	static const QString INTERFACE_WLAN;
 	static const QString INTERFACE_USB;
+	static const QString INTERFACE_GPRS;
 
-	QString apname, encryption, key, interface, network, apn, apid;
-	bool internet;
+	QString hotspotName, encryptionType, encryptionKey, lanInterface, lanNetwork, internetAPName, internetAPType, internetAPID;
+	bool internetEnabled, disablePowerSaving;
 	Enforcement enforcement2g3g;
 
 public:
@@ -45,6 +48,7 @@ public:
     ~MobileHotspotConfiguration();
     void load();
     void save();
+    QString internetInterface() const;
 };
 
 #endif // MOBILEHOTSPOTCONFIGURATION_H
