@@ -18,6 +18,7 @@
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusMessage>
 #include <QtCore/QTimer>
+#include "apnhelper.h"
 #include "mobilehotspotplugin.h"
 #include "dbushelper.h"
 #include "hotspothelper.h"
@@ -148,33 +149,67 @@ void MobileHotspotGUI::about(){
 
 void MobileHotspotGUI::updateDisplayedConfiguration(){
 	ui.lstAccessPoint->clear();
-	ui.lstAccessPoint->addItem(configuration.apname);
-	ui.lstAccessPoint->addItem(configuration.encryption == configuration.ENCRYPTION_WEP ? tr("WEP") : tr("No encryption"));
+	ui.lstAccessPoint->addItem(configuration.hotspotName);
+	ui.lstAccessPoint->addItem(configuration.encryptionType == configuration.ENCRYPTION_WEP ? tr("WEP") : tr("No encryption"));
+	if(configuration.disablePowerSaving)
+		ui.lstAccessPoint->addItem(tr("Disable power-saving"));
 
 	ui.lstInternetAccess->clear();
-	QString s = configuration.apn;
-	if(configuration.enforcement2g3g != IGNORE){
-		s += " (";
-		if(configuration.enforcement2g3g == ENFORCE_2G)
-			s += tr("2G");
-		else if(configuration.enforcement2g3g == ENFORCE_3G)
-			s += tr("3G");
-		else
-			s += tr("2G/3G");
-		s += ")";
+	QString s = configuration.internetAPName;
+	if(s != "" && configuration.internetInterface() == configuration.INTERFACE_GPRS){
+		if(configuration.enforcement2g3g != IGNORE){
+			s += " (";
+			if(configuration.enforcement2g3g == ENFORCE_2G)
+				s += tr("2G");
+			else if(configuration.enforcement2g3g == ENFORCE_3G)
+				s += tr("3G");
+			else
+				s += tr("2G/3G");
+			s += ")";
+		}
 	}
 	ui.lstInternetAccess->addItem(s);
-	ui.lstInternetAccess->addItem(configuration.internet ? tr("With internet") : tr("Without internet"));
-	ui.lstInternetAccess->addItem(configuration.network + "0");
+	ui.lstInternetAccess->addItem(configuration.internetEnabled ? tr("With internet") : tr("Without internet"));
+	ui.lstInternetAccess->addItem(configuration.lanNetwork + "0");
 
 	ui.lstInterfaces->clear();
 	ui.lstInterfaces->addItem(tr("Wifi"), configuration.INTERFACE_WLAN);
 	ui.lstInterfaces->addItem(tr("USB"), configuration.INTERFACE_USB);
-	ui.lstInterfaces->setCurrentIndex(configuration.interface == configuration.INTERFACE_WLAN ? 0 : 1);
-	if(configuration.interface == configuration.INTERFACE_USB)
-		ui.btnAccessPoint->setEnabled(false);
-	else
-		ui.btnAccessPoint->setEnabled(true);
+	ui.lstInterfaces->setCurrentIndex(configuration.lanInterface == configuration.INTERFACE_WLAN ? 0 : 1);
+}
+
+void MobileHotspotGUI::configureInternetAccess(){
+	/** Find available networks **/
+	//TODO
+	/** For now we just call doConfigureInternetAccess() **/
+	doConfigureInternetAccess();
+}
+
+void MobileHotspotGUI::availableAPNsSignal(const QDBusMessage &message){
+	//TODO
+}
+
+void MobileHotspotGUI::availableAPNsEnableSignal(){
+	//TODO
+}
+
+void MobileHotspotGUI::availableAPNsDisableSignal(){
+	//TODO
+}
+
+void MobileHotspotGUI::availableAPNsRequest(){
+	//TODO
+}
+
+void MobileHotspotGUI::doConfigureInternetAccess(){
+	InternetAccessGUI gui(this);
+	gui.setConfiguration(configuration);
+	if(gui.exec() != QDialog::Accepted)
+		return;
+
+	gui.configuration(&configuration);
+	configuration.save();
+	updateDisplayedConfiguration();
 }
 
 void MobileHotspotGUI::configureAccessPoint(){
@@ -183,24 +218,18 @@ void MobileHotspotGUI::configureAccessPoint(){
 	if(gui.exec() != QDialog::Accepted)
 		return;
 
-	gui.getConfiguration(&configuration);
-	configuration.save();
-	updateDisplayedConfiguration();
-}
-
-void MobileHotspotGUI::configureInternetAccess(){
-	InternetAccessGUI gui(this);
-	gui.setConfiguration(configuration);
-	if(gui.exec() != QDialog::Accepted)
-		return;
-
-	gui.getConfiguration(&configuration);
+	gui.configuration(&configuration);
 	configuration.save();
 	updateDisplayedConfiguration();
 }
 
 void MobileHotspotGUI::configureInterface(int index){
-	configuration.interface = ui.lstInterfaces->itemData(index).toString();
+	configuration.lanInterface = ui.lstInterfaces->itemData(index).toString();
+	if(configuration.lanInterface == configuration.INTERFACE_WLAN && configuration.internetAPType != GCONF_APN_TYPE_GPRS){
+		configuration.internetAPID = "";
+		configuration.internetAPType = "";
+		configuration.internetAPName = "";
+	}
 	configuration.save();
 	updateDisplayedConfiguration();
 }
@@ -208,7 +237,7 @@ void MobileHotspotGUI::configureInterface(int index){
 void MobileHotspotGUI::start(bool notification){
 	int ret;
 	/** Find previous enforcement **/
-	if(configuration.internet && configuration.enforcement2g3g != IGNORE){
+	if(configuration.internetEnabled && configuration.enforcement2g3g != IGNORE){
 		ret = DBUSHelper::internetEnforcement2G3G(&previousEnforcement);
 		if(ret != 0){
 			qDebug("WARNING : Cannot get the current level of 2G/3G enforcement, using default value");
@@ -238,6 +267,18 @@ void MobileHotspotGUI::startProcedure(){
 	waitingForPreviousConnection = false;
 	previousConnectionDisableSignal();
 
+	/** Obvious sanity checks **/
+	if(configuration.lanInterface == configuration.INTERFACE_WLAN && configuration.internetInterface() == configuration.INTERFACE_WLAN){
+		/** Both LAN and INET are on WLAN, that is not possible **/
+		QString fail = tr("Error : LAN and Internet are both using the Wifi interface, please use a LAN on USB");
+		QMessageBox::critical(this, tr("Invalid parameters"), fail);
+		return;
+	}
+
+	/** Save scan interval & powersave (if there is one) **/
+	scanInterval = APNHelper::scanInterval();
+	apnPowerSave = APNHelper::apnPowerSave(configuration.internetAPID);
+
 	/** Notify plugins **/
 	QListIterator<QString> pluginsIterator = QListIterator<QString>(sortedPlugins);
 	while(pluginsIterator.hasNext()){
@@ -249,7 +290,6 @@ void MobileHotspotGUI::startProcedure(){
 	}
 
 	try{
-
 		/** Load system modules if necessary **/
 		alreadyLoadedModules.clear();
 		ret = HotspotHelper::loadSystemModules(&alreadyLoadedModules);
@@ -257,10 +297,11 @@ void MobileHotspotGUI::startProcedure(){
 			throw QString(tr("Error while loading system modules, are you running the power kernel ?"));
 
 		/** Internet connection handling **/
-		if(configuration.internet){
+		if(configuration.internetEnabled){
 
-			if(previousConnectionType == "GPRS" && previousConnectionID == configuration.apid)
+			if(previousConnectionType == configuration.internetAPType && previousConnectionID == configuration.internetAPID && configuration.internetInterface() != configuration.INTERFACE_WLAN)
 				/** Nothing to do to the internet connection **/
+				/** In case of USB-Lan and Wifi-Inet we have to disconnect, change powersave & reconnect to prevent route disappearing problem **/
 				qDebug("** Internet connection is already good, skipping this step **");
 			else{
 				/** Disable current internet connection **/
@@ -268,13 +309,20 @@ void MobileHotspotGUI::startProcedure(){
 				if(ret != 0)
 					throw QString(tr("Error while disconnecting previous internet connection"));
 
+				/** USB-Lan Wifi-Inet **/
+				if(configuration.internetInterface() == configuration.INTERFACE_WLAN){
+					/** Change powersave if needed **/
+					if(configuration.disablePowerSaving)
+						APNHelper::setAPNPowerSave(configuration.internetAPID, GCONF_APN_POWER_NOECO);
+				}
+
 				/** Connect to the chosen APN **/
 				ret = HotspotHelper::enableInternetConnection(configuration);
 				if(ret != 0)
 					throw QString(tr("Error while connecting to the chosen APN"));
 			}
 		}
-		else if(configuration.interface == configuration.INTERFACE_WLAN && previousConnectionType.indexOf("WLAN") >= 0){
+		else if(configuration.lanInterface == configuration.INTERFACE_WLAN && previousConnectionType.indexOf("WLAN") >= 0){
 			/** WLAN must be disabled in order to get the adhoc WLAN working **/
 			ret = HotspotHelper::disableInternetConnection(configuration);
 			if(ret != 0)
@@ -283,8 +331,11 @@ void MobileHotspotGUI::startProcedure(){
 		else
 			qDebug("** User requested no internet connection, ignoring it then **");
 
+		/** Disable network automatic search **/
+		APNHelper::setScanInterval(0);
+
 		/** USB vs Wifi **/
-		if(configuration.interface == configuration.INTERFACE_USB){
+		if(configuration.lanInterface == configuration.INTERFACE_USB){
 
 			/** USB mode **/
 			ret = HotspotHelper::checkUSBMode();
@@ -292,7 +343,7 @@ void MobileHotspotGUI::startProcedure(){
 				throw QString(tr("Error while checking USB mode, are you in PC Suite mode ?"));
 
 			/** Prepare USB interface **/
-			ret = HotspotHelper::prepareUSBInterface(configuration, &scanInterval);
+			ret = HotspotHelper::prepareUSBInterface(configuration);
 			if(ret != 0)
 				throw QString(tr("Error while preparing the USB interface"));
 
@@ -300,7 +351,7 @@ void MobileHotspotGUI::startProcedure(){
 		else{
 
 			/** Prepare Wifi interface **/
-			ret = HotspotHelper::prepareWifiInterface(configuration, &scanInterval);
+			ret = HotspotHelper::prepareWifiInterface(configuration);
 			if(ret != 0)
 				throw QString(tr("Error while preparing the Wifi interface"));
 		}
@@ -344,7 +395,7 @@ void MobileHotspotGUI::startProcedure(){
 	}
 
 	/** Enforcement 2G/3G **/
-	if(configuration.internet && configuration.enforcement2g3g != IGNORE){
+	if(configuration.internetEnabled && configuration.enforcement2g3g != IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
 		qDebug("Changing 2g/3g enforcement");
 		ret = 0;
 		if(configuration.enforcement2g3g == ENFORCE_2G && previousEnforcement != ENFORCEMENT_2G)
@@ -412,10 +463,10 @@ void MobileHotspotGUI::stopProcedure(){
 	}
 
 	/** USB vs Wifi **/
-	if(configuration.interface == configuration.INTERFACE_USB){
+	if(configuration.lanInterface == configuration.INTERFACE_USB){
 
 		/** Unprepare USB interface **/
-		ret = HotspotHelper::unprepareUSBInterface(configuration, scanInterval);
+		ret = HotspotHelper::unprepareUSBInterface(configuration);
 		if(ret != 0){
 			qDebug("Error while unpreparing USB interface");
 			success = false;
@@ -424,18 +475,22 @@ void MobileHotspotGUI::stopProcedure(){
 	else{
 
 		/** Unprepare Wifi interface **/
-		ret = HotspotHelper::unprepareWifiInterface(configuration, scanInterval);
+		ret = HotspotHelper::unprepareWifiInterface(configuration);
 		if(ret != 0){
 			qDebug("Error while unpreparing Wifi interface");
 			success = false;
 		}
 	}
 
-	/** Internet connection handling **/
-	if(configuration.internet){
+	/** Restore scan interval **/
+	APNHelper::setScanInterval(scanInterval);
 
-		if(previousConnectionType == "GPRS" && previousConnectionID == configuration.apid)
+	/** Internet connection handling **/
+	if(configuration.internetEnabled){
+
+		if(previousConnectionType == configuration.internetAPType && previousConnectionID == configuration.internetAPID && configuration.internetInterface() != configuration.INTERFACE_WLAN)
 			/** Current connection == previous connection **/
+			/** In case of USB-Lan and Wifi-Inet we have to disconnect, change powersave & reconnect **/
 			qDebug("** Previous connection was the same, nothing to do to the internet connection **");
 		else{
 			/** Disable current internet connection **/
@@ -445,6 +500,13 @@ void MobileHotspotGUI::stopProcedure(){
 				success = false;
 			}
 
+			/** USB-Lan Wifi-Inet **/
+			if(configuration.internetInterface() == configuration.INTERFACE_WLAN){
+				/** Change powersave if needed **/
+				if(configuration.disablePowerSaving)
+					APNHelper::setAPNPowerSave(configuration.internetAPID, apnPowerSave);
+			}
+
 			if(previousConnectionID != ""){
 				/** Restore previous internet connection **/
 				qDebug("** Restoring previous internet connection **");
@@ -458,7 +520,7 @@ void MobileHotspotGUI::stopProcedure(){
 				qDebug("** There was no previous connection, so no reconnection to do **");
 		}
 	}
-	else if(configuration.interface == configuration.INTERFACE_WLAN && previousConnectionType.indexOf("WLAN") >= 0){
+	else if(configuration.lanInterface == configuration.INTERFACE_WLAN && previousConnectionType.indexOf("WLAN") >= 0){
 		/** We need to restore disabled WLAN **/
 		ret = DBUSHelper::internetConnect(previousConnectionID);
 		if(ret != 0){
@@ -491,7 +553,7 @@ void MobileHotspotGUI::stopProcedure(){
 	}
 
 	/** Enforcement 2G/3G **/
-	if(configuration.internet && configuration.enforcement2g3g != IGNORE){
+	if(configuration.internetEnabled && configuration.enforcement2g3g != IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
 		qDebug("Restoring original 2g/3g enforcement");
 		ret = DBUSHelper::setInternetEnforcement2G3G(previousEnforcement);
 		if(ret != 0)
